.. _configuration:

Configuration
=============

After you hook ``django-projector`` into your project [1]_
you should probably change some of configuration variables. All of them have
default values but some functionality is turned off at the beginning (for
instance repository backend [2]_).


.. [1] See :ref:`installation`
.. [2] See :ref:`repository_backend`
